Interface: ScriptableScalePointLabelContext | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ScriptableScalePointLabelContext

## # Properties

### # chart

• chart: `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`>

#### # Defined in

index.esm.d.ts:1348
(opens new window)

### # index

• index: `number`

#### # Defined in

index.esm.d.ts:1350
(opens new window)

### # label

• label: `string`

#### # Defined in

index.esm.d.ts:1351
(opens new window)

### # scale

• scale: `Scale`<`CoreScaleOptions`>

#### # Defined in

index.esm.d.ts:1349
(opens new window)

### # type

• type: `string`

#### # Defined in

index.esm.d.ts:1352
(opens new window)